@@ -3,9 +3,9 @@
 '''
 @File    :   logHelper.py
 @Time    :   2019/02/28
-@Author  :   Yaron Huang 
-@Version :   1.0
-@Contact :   yaronhuang@qq.com
+@Author  :   Yaronzz 
+@Version :   2.0
+@Contact :   yaronhuang@foxmail.com
 @Desc    :   LOG FILE TOOL
 '''
 import os
