@@ -4,9 +4,9 @@
 '''
 @File    :   systemHelper.py
 @Time    :   2018/12/20
-@Author  :   Yaron Huang 
-@Version :   1.0
-@Contact :   yaronhuang@qq.com
+@Author  :   Yaronzz 
+@Version :   2.0
+@Contact :   yaronhuang@foxmail.com
 @Desc    :   
 '''
 import os
